rnalysis.filtering.CountFilter.norm\_reads\_with\_size\_factor
================================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: CountFilter.norm_reads_with_size_factor
